==> libreoffice-l10n_4.2.7.orig.tar.xz: libreoffice-4.2.7/lotuswordpro/source/filter/xfilter/xftabstyle.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
/*************************************************************************
 * @file
 * Tab style for paragraph.include tab offset and tab char properties.
 ************************************************************************/
#include "xftabstyle.hxx"

XFTabStyle::XFTabStyle()
{
    m_eType = enumXFTabNone;
    m_fLength = 0;
}

void    XFTabStyle::ToXml(IXFStream *pStrm)
{
    IXFAttrList *pAttrList = pStrm->GetAttrList();
    pAttrList->Clear();

    pAttrList->AddAttribute( A2OUSTR("style:position"), DoubleToOUString(m_fLength) + A2OUSTR("cm") );
    switch(m_eType)
    {
    case enumXFTabLeft:
        pAttrList->AddAttribute( A2OUSTR("style:type"), A2OUSTR("left") );
        break;
    case enumXFTabCenter:
        pAttrList->AddAttribute( A2OUSTR("style:type"), A2OUSTR("center") );
        break;
    case enumXFTabRight:
        pAttrList->AddAttribute( A2OUSTR("style:type"), A2OUSTR("right") );
        break;
    case enumXFTabChar:
        pAttrList->AddAttribute( A2OUSTR("style:type"), A2OUSTR("char") );
        break;
    default:
        break;
    }
    //delimiter:
    if( m_eType == enumXFTabChar )
        pAttrList->AddAttribute( A2OUSTR("style:char"), m_strDelimiter );
    //leader char:
    if( !m_strLeader.isEmpty() )
        pAttrList->AddAttribute( A2OUSTR("style:leader-char"), m_strLeader );

    pStrm->StartElement( A2OUSTR("style:tab-stop") );
    pStrm->EndElement( A2OUSTR("style:tab-stop") );
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-l10n_4.4.6~rc3.orig.tar.xz: libreoffice-4.4.6~rc3/lotuswordpro/source/filter/xfilter/xftabstyle.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
/*************************************************************************
 * @file
 * Tab style for paragraph.include tab offset and tab char properties.
 ************************************************************************/
#include "xftabstyle.hxx"

XFTabStyle::XFTabStyle()
{
    m_eType = enumXFTabNone;
    m_fLength = 0;
}

void XFTabStyle::ToXml(IXFStream *pStrm)
{
    IXFAttrList *pAttrList = pStrm->GetAttrList();
    pAttrList->Clear();

    pAttrList->AddAttribute( "style:position", OUString::number(m_fLength) + "cm" );
    switch(m_eType)
    {
    case enumXFTabLeft:
        pAttrList->AddAttribute( "style:type", "left" );
        break;
    case enumXFTabCenter:
        pAttrList->AddAttribute( "style:type", "center" );
        break;
    case enumXFTabRight:
        pAttrList->AddAttribute( "style:type", "right" );
        break;
    case enumXFTabChar:
        pAttrList->AddAttribute( "style:type", "char" );
        break;
    default:
        break;
    }
    //delimiter:
    if( m_eType == enumXFTabChar )
        pAttrList->AddAttribute( "style:char", m_strDelimiter );
    //leader char:
    if( !m_strLeader.isEmpty() )
        pAttrList->AddAttribute( "style:leader-char", m_strLeader );

    pStrm->StartElement( "style:tab-stop" );
    pStrm->EndElement( "style:tab-stop" );
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
